@@ -41,12 +41,6 @@
 #define d(x)
 
 /*Prototypes*/
-static gint gw_summary_header_load (CamelFolderSummary *, FILE *);
-static gint gw_summary_header_save (CamelFolderSummary *, FILE *);
-
-static CamelMessageInfo *gw_message_info_migrate (CamelFolderSummary *s, FILE *in);
-
-static CamelMessageContentInfo * gw_content_info_migrate (CamelFolderSummary *s, FILE *in);
 static gboolean gw_info_set_flags (CamelMessageInfo *info, guint32 flags, guint32 set);
 
 static gboolean summary_header_from_db (CamelFolderSummary *s, CamelFIRecord *mir);
@@ -85,10 +79,6 @@ camel_groupwise_summary_class_init (CamelGroupwiseSummaryClass *class)
 	folder_summary_class->message_info_size = sizeof (CamelGroupwiseMessageInfo);
 	folder_summary_class->content_info_size = sizeof (CamelGroupwiseMessageContentInfo);
 	folder_summary_class->message_info_clone = gw_message_info_clone;
-	folder_summary_class->summary_header_load = gw_summary_header_load;
-	folder_summary_class->summary_header_save = gw_summary_header_save;
-	folder_summary_class->message_info_migrate = gw_message_info_migrate;
-	folder_summary_class->content_info_migrate = gw_content_info_migrate;
 	folder_summary_class->info_set_flags = gw_info_set_flags;
 	folder_summary_class->summary_header_to_db = summary_header_to_db;
 	folder_summary_class->summary_header_from_db = summary_header_from_db;
@@ -105,7 +95,6 @@ camel_groupwise_summary_init (CamelGroupwiseSummary *gw_summary)
 
 /**
  * camel_groupwise_summary_new:
- * @filename: the file to store the summary in.
  *
  * This will create a new CamelGroupwiseSummary object and read in the
  * summary data from disk, if it exists.
@@ -113,14 +102,12 @@ camel_groupwise_summary_init (CamelGroupwiseSummary *gw_summary)
  * Returns: A new CamelGroupwiseSummary object.
  **/
 CamelFolderSummary *
-camel_groupwise_summary_new (struct _CamelFolder *folder,
-                             const gchar *filename)
+camel_groupwise_summary_new (struct _CamelFolder *folder)
 {
 	CamelFolderSummary *summary;
 
 	summary = g_object_new (CAMEL_TYPE_GROUPWISE_SUMMARY, "folder", folder, NULL);
 	camel_folder_summary_set_build_content (summary, TRUE);
-	camel_folder_summary_set_filename (summary, filename);
 
 	camel_folder_summary_load_from_db (summary, NULL);
 
@@ -149,24 +136,6 @@ summary_header_from_db (CamelFolderSummary *s,
 	return TRUE;
 }
 
-static gint
-gw_summary_header_load (CamelFolderSummary *s,
-                        FILE *in)
-{
-	CamelGroupwiseSummary *gms = CAMEL_GROUPWISE_SUMMARY (s);
-
-	if (CAMEL_FOLDER_SUMMARY_CLASS (camel_groupwise_summary_parent_class)->summary_header_load (s, in) == -1)
-		return -1;
-
-	if (camel_file_util_decode_fixed_int32 (in, &gms->version) == -1
-			|| camel_file_util_decode_fixed_int32 (in, &gms->validity) == -1)
-		return -1;
-
-	if (camel_file_util_decode_string (in, &gms->time_string) == -1)
-		return -1;
-	return 0;
-}
-
 static CamelFIRecord *
 summary_header_to_db (CamelFolderSummary *s,
                       GError **error)
@@ -184,20 +153,6 @@ summary_header_to_db (CamelFolderSummary *s,
 
 }
 
-static gint
-gw_summary_header_save (CamelFolderSummary *s,
-                        FILE *out)
-{
-	CamelGroupwiseSummary *gms = CAMEL_GROUPWISE_SUMMARY (s);
-
-	if (CAMEL_FOLDER_SUMMARY_CLASS (camel_groupwise_summary_parent_class)->summary_header_save (s, out) == -1)
-		return -1;
-
-	camel_file_util_encode_fixed_int32 (out, CAMEL_GW_SUMMARY_VERSION);
-	camel_file_util_encode_fixed_int32 (out, gms->validity);
-	return camel_file_util_encode_string (out, gms->time_string);
-}
-
 static CamelMessageInfo *
 message_info_from_db (CamelFolderSummary *s,
                       CamelMIRecord *mir)
@@ -214,26 +169,6 @@ message_info_from_db (CamelFolderSummary *s,
 
 	return info;}
 
-static CamelMessageInfo *
-gw_message_info_migrate (CamelFolderSummary *s,
-			 FILE *in)
-{
-	CamelMessageInfo *info;
-	CamelGroupwiseMessageInfo *gw_info;
-
-	info = CAMEL_FOLDER_SUMMARY_CLASS (camel_groupwise_summary_parent_class)->message_info_migrate (s,in);
-	if (info) {
-		gw_info = (CamelGroupwiseMessageInfo *) info;
-		if (camel_file_util_decode_uint32 (in, &gw_info->server_flags) == -1)
-			goto error;
-	}
-
-	return info;
-error:
-	camel_message_info_free (info);
-	return NULL;
-}
-
 static CamelMIRecord *
 message_info_to_db (CamelFolderSummary *s,
                     CamelMessageInfo *info)
@@ -269,16 +204,6 @@ content_info_from_db (CamelFolderSummary *s,
 		return camel_folder_summary_content_info_new (s);
 }
 
-static CamelMessageContentInfo *
-gw_content_info_migrate (CamelFolderSummary *s,
-                         FILE *in)
-{
-	if (fgetc (in))
-		return CAMEL_FOLDER_SUMMARY_CLASS (camel_groupwise_summary_parent_class)->content_info_migrate (s, in);
-	else
-		return camel_folder_summary_content_info_new (s);
-}
-
 static gboolean
 content_info_to_db (CamelFolderSummary *s,
                     CamelMessageContentInfo *info,
