@@ -27,6 +27,8 @@
 
 #include <string.h>
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
+#include <fcntl.h>
 #include <gtk/gtk.h>
 #include <libecal/e-cal-client.h>
 
@@ -39,6 +41,10 @@
 
 #include "gw-ui.h"
 
+#ifndef O_BINARY
+#define O_BINARY 0
+#endif
+
 typedef struct {
 	ECalClient *client;
 	icalcomponent *icalcomp;
@@ -78,7 +84,8 @@ receive_objects (gpointer data)
 }
 
 static icalproperty *
-find_attendee (icalcomponent *ical_comp, const gchar *address)
+find_attendee (icalcomponent *ical_comp,
+               const gchar *address)
 {
 	icalproperty *prop;
 
@@ -110,7 +117,9 @@ find_attendee (icalcomponent *ical_comp, const gchar *address)
 	return prop;
 }
 static void
-change_status (icalcomponent *ical_comp, const gchar *address, icalparameter_partstat status)
+change_status (icalcomponent *ical_comp,
+               const gchar *address,
+               icalparameter_partstat status)
 {
 	icalproperty *prop;
 
@@ -136,7 +145,8 @@ change_status (icalcomponent *ical_comp, const gchar *address, icalparameter_par
 }
 
 static void
-process_meeting (ECalendarView *cal_view, icalparameter_partstat status)
+process_meeting (ECalendarView *cal_view,
+                 icalparameter_partstat status)
 {
 	GList *selected;
 	icalcomponent *clone;
@@ -229,7 +239,8 @@ get_calendar_view (EShellView *shell_view)
 }
 
 void
-gw_meeting_accept_cb (GtkAction *action, EShellView *shell_view)
+gw_meeting_accept_cb (GtkAction *action,
+                      EShellView *shell_view)
 {
 	ECalendarView *cal_view = get_calendar_view (shell_view);
 	g_return_if_fail (cal_view != NULL);
@@ -238,7 +249,8 @@ gw_meeting_accept_cb (GtkAction *action, EShellView *shell_view)
 }
 
 void
-gw_meeting_accept_tentative_cb (GtkAction *action, EShellView *shell_view)
+gw_meeting_accept_tentative_cb (GtkAction *action,
+                                EShellView *shell_view)
 {
 	ECalendarView *cal_view = get_calendar_view (shell_view);
 	g_return_if_fail (cal_view != NULL);
@@ -247,7 +259,8 @@ gw_meeting_accept_tentative_cb (GtkAction *action, EShellView *shell_view)
 }
 
 void
-gw_meeting_decline_cb (GtkAction *action, EShellView *shell_view)
+gw_meeting_decline_cb (GtkAction *action,
+                       EShellView *shell_view)
 {
 	ECalendarView *cal_view = get_calendar_view (shell_view);
 	g_return_if_fail (cal_view != NULL);
@@ -262,7 +275,9 @@ typedef struct {
 } ThreadData;
 
 static void
-add_retract_data (ECalComponent *comp, const gchar *retract_comment, CalObjModType mod)
+add_retract_data (ECalComponent *comp,
+                  const gchar *retract_comment,
+                  CalObjModType mod)
 {
 	icalcomponent *icalcomp = NULL;
 	icalproperty *icalprop = NULL;
@@ -340,7 +355,8 @@ retract_object (gpointer val)
 }
 
 static void
-object_created_cb (CompEditor *ce, gpointer data)
+object_created_cb (CompEditor *ce,
+                   gpointer data)
 {
 	GThread *thread = NULL;
 	gint response;
@@ -364,7 +380,8 @@ object_created_cb (CompEditor *ce, gpointer data)
 }
 
 void
-gw_resend_meeting_cb (GtkAction *action, EShellView *shell_view)
+gw_resend_meeting_cb (GtkAction *action,
+                      EShellView *shell_view)
 {
 	GList *selected;
 	ECalendarView *cal_view = get_calendar_view (shell_view);
@@ -414,18 +431,70 @@ gw_resend_meeting_cb (GtkAction *action, EShellView *shell_view)
 		if (resend)
 		{
 			guint flags = 0;
+			gint fd;
 			gchar *new_uid = NULL;
+			const gchar *old_uid;
 			CompEditor *ce;
 			icalcomponent *icalcomp;
+			gchar *dest_url, *dest_file;
+			GSList *l, *attach_list = NULL, *new_attach_list = NULL;
 
 			flags |= COMP_EDITOR_NEW_ITEM;
 			flags |= COMP_EDITOR_MEETING;
 			flags |= COMP_EDITOR_USER_ORG;
 
 			new_comp = e_cal_component_clone (comp);
+			e_cal_component_get_uid (comp, &old_uid);
 			new_uid = e_cal_component_gen_uid ();
 			e_cal_component_set_recurid (new_comp, NULL);
 			e_cal_component_set_uid (new_comp, new_uid);
+			e_cal_component_get_attachment_list (new_comp, &attach_list);
+
+			for (l = attach_list; l; l = l->next) {
+				gchar *sfname = g_filename_from_uri ((gchar *)l->data, NULL, NULL);
+				gchar *filename, *new_filename;
+				gchar *cache_dir, *temp_filename;
+				GMappedFile *mapped_file;
+				GError *error = NULL;
+
+				mapped_file = g_mapped_file_new (sfname, FALSE, &error);
+				if (!mapped_file) {
+					g_error_free (error);
+					continue;
+				}
+				filename = g_path_get_basename (sfname);
+				cache_dir = g_path_get_dirname (sfname);
+				temp_filename = g_strdup (filename + strlen(old_uid)+1);
+				new_filename = g_strconcat (new_uid, "-", temp_filename, NULL);
+				g_free (temp_filename);
+				g_free (filename);
+				dest_file = g_build_filename (cache_dir, new_filename, NULL);
+				g_free (new_filename);
+				g_free (cache_dir);
+				fd = g_open (dest_file, O_RDWR|O_CREAT|O_TRUNC|O_BINARY, 0600);
+				if (fd == -1) {
+					/* TODO handle error conditions */
+				} else if (write (fd, g_mapped_file_get_contents (mapped_file),
+					  g_mapped_file_get_length (mapped_file)) == -1) {
+					/* TODO handle error condition */
+				}
+
+			#if GLIB_CHECK_VERSION(2,21,3)
+				g_mapped_file_unref (mapped_file);
+			#else
+				g_mapped_file_free (mapped_file);
+			#endif
+				if (fd != -1)
+					close (fd);
+				dest_url = g_filename_to_uri (dest_file, NULL, NULL);
+				g_free (dest_file);
+				new_attach_list = g_slist_append (new_attach_list, dest_url);
+			}
+			e_cal_component_set_attachment_list (new_comp, new_attach_list);
+			for (l = new_attach_list; l != NULL; l = l->next)
+				g_free (l->data);
+			g_slist_free (new_attach_list);
+
 			icalcomp = icalcomponent_new_clone (e_cal_component_get_icalcomponent (new_comp));
 			ce = e_calendar_view_open_event_with_flags (cal_view, data->client, icalcomp, flags);
 
